Density, distribution function, quantile function and random generation for the GGPD distribution.
dggpd(x, xi, sigma, u, mu, eta, log = FALSE)pggpd(q, xi, sigma, u, mu, eta, lower.tail = TRUE)
qggpd(p, xi, sigma, u, mu, eta, lower.tail = TRUE)
rggpd(N, xi, sigma, u, mu, eta)
The GGPD distribution is an extreme value mixture model with density $$f_{GGPD}(x|\xi,\sigma,u,\mu,\eta,w)=\left\{\begin{array}{ll} f_{GA}(x|\mu,\eta), & x\leq u \\ (1-F_{GA}(u|\mu,\eta))f_{GPD}(x|\xi,\sigma,u), &\mbox{otherwise}, \end{array}\right.$$ where \(f_{GA}\) is the density of the Gamma parametrized by mean \(\mu\) and shape \(\eta\), \(F_{GA}\) is the distribution function of the Gamma and \(f_{GPD}\) is the density of the Generalized Pareto Distribution, i.e. $$f_{GPD}(x|\xi,\sigma,u)=\left\{\begin{array}{ll} 1- (1+\frac{\xi}{\sigma}(x-u))^{-1/\xi}, & \mbox{if } \xi\neq 0,\\ 1- \exp\left(-\frac{x-u}{\sigma}\right), & \mbox{if } \xi = 0, \end{array}\right.$$
where \(\xi\) is a shape parameter, \(\sigma > 0\) is a scale parameter and \(u>0\) is a threshold.
dggpd gives the density, pggpd gives the distribution function, qggpd gives the quantile function, and rggpd generates random deviates. The length of the result is determined by N for rggpd and by the length of x, q or p otherwise.
vector of quantiles.
shape parameter of the tail GPD (scalar).
scale parameter of the tail GPD (scalar).
threshold parameter of the tail GPD (scalar).
mean of the gamma bulk (scalar).
shape of the gamma bulk (scalar).
logical; if TRUE, probabilities p are given as log(p).
logical; if TRUE (default), probabilities are \(P(X\leq x)\) otherwise \(P(X>x)\).
vector of probabilities.
number of observations.
Behrens, Cibele N., Hedibert F. Lopes, and Dani Gamerman. "Bayesian analysis of extreme events with threshold estimation." Statistical Modelling 4.3 (2004): 227-244.
dggpd(3, xi = 0.5, sigma = 2, u = 5, mu = 3, eta = 3)
Run the code above in your browser using DataLab